C Curl Extension for PyOTA
==========================
.. DANGER::
   ⚠️ **THIS VERSION IS EXPERIMENTAL AND HAS NOT BEEN VETTED FOR STABILITY/SECURITY YET; DO NOT USE IN PRODUCTION CODE!!!** ⚠️ 

This is an extension for the crypto functionality in `PyOTA`_, the Python API
for IOTA.  When installed, it will significantly boost the performance of
PyOTA's crypto functionality.

This extension is installed as an add-on to the ``pyota`` package::

   pip install pyota[ccurl]

.. _PyOTA: https://pypi.python.org/pypi/PyOTA
